@@ -9,7 +9,7 @@ from ConfigParser import SafeConfigParser
 import dbus
 from dbus.mainloop.glib import DBusGMainLoop
 
-version = "2.2-9"
+version = "2.2-10"
 trackingEnabled = True
 stopTracking = True
 stopWhenIdle = False
@@ -133,7 +133,7 @@ class Window(object):
                     connectedIcon = self.parser.get('options', 'connectedIcon')
                 else:
                     self.parser.set('options', 'connectedIcon', str(connectedIcon))
-                if self.parser.has_option('options', 'keepWifiPM'):
+                if self.parser.has_option('options', 'wifiPMIcon'):
                     wifiPMIcon = self.parser.getboolean('options', 'wifiPMIcon')
                 else:
                     self.parser.set('options', 'wifiPMIcon', str(wifiPMIcon))
